''
'' This code is part of https://demo.grapecity.com.cn/gcword.
'' Copyright (c) MESCIUS inc. All rights reserved.
''
Imports System
Imports System.Collections.Generic
Imports System.Text
Imports System.Threading
Imports System.Reflection
Imports System.IO
Imports System.Linq
Imports System.Drawing
Imports System.Runtime.CompilerServices

Imports GrapeCity.Documents.Word
Imports GrapeCity.Documents.Pdf
Imports GrapeCity.Documents.Drawing

Public Module Util

    Private s_gen As Integer = 0
    Private s_fixedTime As DateTime = New DateTime(1989, 6, 21, 1, 23, 45, DateTimeKind.Local)

    Public Property NoRandom As Boolean = False

    Public Function NewRandom() As Random
        If NoRandom Then
            Return New Random(0)
        Else
            Return New Random(Convert.ToInt32(DateTime.Now.Ticks And Int32.MaxValue) + Interlocked.Increment(s_gen))
        End If
    End Function

    Public Function TimeNow() As DateTime
        If NoRandom Then
            Return s_fixedTime
        Else
            Return DateTime.Now
        End If
    End Function

    Public Function LoremIpsum(
            Optional ByVal numParagraphs As Integer = 5,
            Optional ByVal minSentences As Integer = 5,
            Optional ByVal maxSentences As Integer = 10,
            Optional ByVal minWords As Integer = 5,
            Optional ByVal maxWords As Integer = 30) As List(Of String)

        Dim result = New List(Of String)
        For p = 1 To numParagraphs
            result.Add(LoremIpsumPar(minSentences, maxSentences, minWords, maxWords))
        Next
        Return result
    End Function

    '' https://stackoverflow.com/questions/4286487/is-there-any-lorem-ipsum-generator-in-c
    Public Function LoremIpsumPar(
            Optional ByVal minSentences As Integer = 5,
            Optional ByVal maxSentences As Integer = 10,
            Optional ByVal minWords As Integer = 5,
            Optional ByVal maxWords As Integer = 30) As String

        Dim words =
            {
                "lorem", "ipsum", "dolor", "sit", "amet", "consectetur", "adipiscing", "elit", "mauris", "id", "volutpat",
                "tellus", "ullamcorper", "sem", "praesent", "et", "ante", "laoreet", "lobortis", "nunc", "congue",
                "nisi", "donec", "ac", "tempus", "sed", "feugiat", "pulvinar", "pharetra", "turpis", "nonummy",
                "at", "felis", "eget", "molestie", "euismod", "non", "aliquet", "diam", "proin", "mi", "nibh",
                "massa", "tincidunt", "ut", "dolore", "magna", "aliquam", "erat"
            }

        Dim commaMax = 10
        Dim rnd = NewRandom()
        Dim numSentences As Integer = rnd.Next(maxSentences - minSentences) + minSentences + 1
        Dim numWords As Integer = rnd.Next(maxWords - minWords) + minWords + 1

        Dim par = New StringBuilder()
        For s = 1 To numSentences
            For w = 1 To numWords
                Dim word As String = words(rnd.Next(words.Length))
                If w = 1 Then
                    par.Append(Char.ToUpper(word(0)))
                    par.Append(word.Substring(1))
                Else
                    If rnd.Next(commaMax) = 0 Then
                        par.Append(","c)
                    End If
                    par.Append(" "c)
                    par.Append(word)
                End If
            Next
            par.Append(". ")
        Next
        Return par.ToString()
    End Function

    '' https://stackoverflow.com/questions/273313/randomize-a-listt
    <Extension()>
    Public Sub Shuffle(Of t)(ByVal list As IList(Of t))
        Dim rnd = NewRandom()
        Dim n = list.Count
        While (n > 1)
            n -= 1
            Dim k = rnd.Next(n + 1)
            Dim value = list(k)
            list(k) = list(n)
            list(n) = value
        End While
    End Sub

    ''' <summary>
    ''' Adds a note to the document - a text fragment on a colored background.
    ''' Used to insert meta info into sample documents.
    ''' </summary>
    ''' <param name="text">The text to draw.</param>
    ''' <param name="page">The page to draw on.</param>
    ''' <param name="bounds">The text bounds. If null, whole page with 1" margins all around is used.</param>
    ''' <returns>The actual rectangle occupied by the note.</returns>
    Public Function AddNote(ByVal text As String, ByVal page As Page, Optional ByVal bounds As Nullable(Of RectangleF) = Nothing) As RectangleF
        Dim g = page.Graphics
        Dim tl = g.CreateTextLayout()
        Dim pad = g.Resolution / 8.0F
        tl.DefaultFormat.Font = StandardFonts.Helvetica
        tl.DefaultFormat.FontSize = 12
        If Not bounds.HasValue Then
            Dim margin = g.Resolution ' 1" margins by default
            bounds = New RectangleF(margin, margin, page.Size.Width - margin * 2, page.Size.Height - margin * 2)
        End If
        tl.MaxWidth = bounds.Value.Width
        tl.MaxHeight = bounds.Value.Height
        tl.MarginLeft = pad
        tl.MarginRight = pad
        tl.MarginTop = pad
        tl.MarginBottom = pad
        tl.Append(text)
        tl.PerformLayout(True)

        Dim rect = tl.ContentRectangle
        rect.Offset(bounds.Value.Location)
        rect.Inflate(pad, pad)

        g.FillRectangle(rect, Color.FromArgb(213, 240, 221))
        g.DrawRectangle(rect, Color.FromArgb(59, 170, 92), 0.5F)
        g.DrawTextLayout(tl, bounds.Value.Location)

        Return rect
    End Function

    ''' <summary>
    ''' Set all page margins to 0.5".
    ''' </summary>
    ''' <param name="doc">The target document.</param>
    Public Sub SetNarrowMargins(ByVal doc As GcWordDocument)
        Dim margin = 36
        doc.Body.Sections(0).PageSetup.Margin.Top = margin
        doc.Body.Sections(0).PageSetup.Margin.Bottom = margin
        doc.Body.Sections(0).PageSetup.Margin.Left = margin
        doc.Body.Sections(0).PageSetup.Margin.Right = margin
    End Sub
End Module
