''
'' This code is part of https://demo.grapecity.com.cn/gcword.
'' Copyright (c) MESCIUS inc. All rights reserved.
''
Imports System
Imports System.IO
Imports System.Diagnostics
Imports System.Reflection
Imports GrapeCity.Documents.Word
Imports GrapeCity.Documents.Word.Layout
Imports GrapeCity.Documents.Text
''
'' This program creates an instance of the TateChuYoko class and uses it to generate a Word file.
'' The file is also saved as PDF (using GcWordDocument.SaveAsPdf() extension method).
'' The GrapeCity packages needed to build and run this sample are available on NuGet.org.
''
'' Command line switches:
'' /y, -y -- assume all defaults, overwrite existing files.
'' /q, -q -- quiet operation (ignored unless /y is specified).
'' /n, -n -- generate repeatable 'random' data.
'' /f path, -f path -- use 'name' as base file path/name.
''
Module Program
    Sub Main(args As String())
        Dim yes2all = false
        Dim quiet = false
        Dim norandom = False
        Dim outMs As MemoryStream = Nothing
        Dim outTw As TextWriter = Nothing
        Try
            Dim fname = "TateChuYoko"
            For i = 0 to args.Length - 1
                Select Case args(i)
                    Case "/y", "-y"
                        yes2all = True
                    Case "/q", "-q"
                        quiet = True
                    Case "/n", "-n"
                        norandom = True
                    Case "/f", "-f"
                        If i + 1 < args.Length Then
                            i += 1
                            If Directory.Exists(args(i)) Then
                                fname = Path.Combine(args(i), fname)
                            Else
                                fname = args(i)
                            End If
                        End If
                End Select
            Next i
            If norandom Then
                Util.NoRandom = True
            End If
            If Not yes2all Then
                quiet = False
            End If
            If quiet Then
                outMs = New MemoryStream()
                outTw = New StreamWriter(outMs)
                Console.SetOut(outTw)
            End If

            Dim lk = Environment.GetEnvironmentVariable("DOCSOL_LKEY")
            if Not String.IsNullOrEmpty(lk) Then
                GcWordDocument.SetLicenseKey(lk)
            End If

            Dim docxName = Path.ChangeExtension(fname, ".docx")
            Dim pdfName = Path.ChangeExtension(fname, ".pdf")
            Dim tiffName = Path.ChangeExtension(fname, ".tiff")

            If Not yes2all Then
                Console.WriteLine($"Press ENTER to create '{docxName}' in the current directory,\nor enter an alternative file name:")
                Dim t = Console.ReadLine()
                If Not String.IsNullOrWhiteSpace(t) Then
                    docxName = t
                End If
                docxName = Path.GetFullPath(docxName)
                If (File.Exists(docxName)) Then
                    Console.WriteLine($"'{docxName}' exists.\nOVERWRITE (Y/n)?")
                    Dim yesno = Console.ReadLine()
                    If yesno.ToLower() = "n" Then
                        Console.WriteLine("Aborted.")
                        Return
                    End If
                End If
            End If
            If Not quiet Then
                Console.WriteLine($"Generating '{docxName}'...")
            End If
            Dim sample = New DsWordWeb.Demos.TateChuYoko()
            Dim docx = sample.CreateDocx()
            docx.Save(docxName)
            If Not quiet Then
                Console.WriteLine($"Created '{docxName}' successfully.")
            End If

            '' Export to PDF or images does not yet fully support some Word features,
            '' for samples demoing those features export is disabled by default:
            Dim canExport = True
            If canExport Then
                If Not yes2all Then
                    If File.Exists(pdfName) Then
                        Console.WriteLine($"'{pdfName}' exists.\nOVERWRITE (Y/n)?")
                        Dim yesno = Console.ReadLine()
                        If yesno.ToLower() = "n" Then
                            Console.WriteLine("Aborted.")
                            Return
                        End If
                    End If
                    If File.Exists(tiffName) Then
                        Console.WriteLine($"'{tiffName}' exists.\nOVERWRITE (Y/n)?")
                        Dim yesno = Console.ReadLine()
                        If yesno.ToLower() = "n" Then
                            Console.WriteLine("Aborted.")
                            Return
                        End If
                    End If
                End If
                Dim wls As WordLayoutSettings = GetType(DsWordWeb.Demos.TateChuYoko).GetMethod("GetWordLayoutSettings", BindingFlags.Static Or BindingFlags.Public)?.Invoke(Nothing, Nothing)
                Dim pdfs As PdfOutputSettings = GetType(DsWordWeb.Demos.TateChuYoko).GetMethod("GetPdfOutputSettings", BindingFlags.Static Or BindingFlags.Public)?.Invoke(Nothing, Nothing)
                If Not quiet Then
                    Console.WriteLine($"Generating '{pdfName}' and '{tiffName}'...")
                End If
                Using layout = New GcWordLayout(docx, wls)
                    layout.SaveAsPdf(pdfName, Nothing, pdfs)
                    layout.SaveAsTiff(tiffName)
                End Using
            End If

            '' Uncomment to open the generated DOCX file:
            '' Dim psi = new ProcessStartInfo() With { .FileName = docxName, .UseShellExecute = true }
            '' Process.Start(psi)

            '' Uncomment to open the generated PDF file:
            '' Dim psiPdf = new ProcessStartInfo() With { .FileName = pdfName, .UseShellExecute = true }
            '' Process.Start(psiPdf)

            '' Uncomment to open the generated TIFF file:
            '' Dim psiTiff = new ProcessStartInfo() With { .FileName = tiffName, .UseShellExecute = true }
            '' Process.Start(psiTiff)
        Catch ex As Exception
            Console.Error.WriteLine($"Error: {ex.Message}")
            If ex.InnerException IsNot Nothing Then
                Console.Error.WriteLine($"InnerException: {ex.InnerException.Message}")
            End If
        Finally
            If Not yes2all Then
                Console.WriteLine("Press any key to exit...")
                Console.ReadKey()
            End If
            If quiet Then
                outTw.Dispose()
                outMs.Dispose()
            End If
        End Try
    End Sub
End Module
